@@ -15,7 +15,6 @@
 
 from __future__ import print_function
 
-from collections import Mapping
 import inspect
 import os
 import re
@@ -29,18 +28,23 @@ if sys.version_info < (3,):
     from SimpleXMLRPCServer import SimpleXMLRPCServer
     from StringIO import StringIO
     from xmlrpclib import Binary, ServerProxy
+    from collections import Mapping
     PY2, PY3 = True, False
+    def getfullargspec(func):
+        return inspect.getargspec(func) + ([], None, {})
 else:
+    from inspect import getfullargspec
     from io import StringIO
     from xmlrpc.client import Binary, ServerProxy
     from xmlrpc.server import SimpleXMLRPCServer
+    from collections.abc import Mapping
     PY2, PY3 = False, True
     unicode = str
     long = int
 
 
 __all__ = ['RobotRemoteServer', 'stop_remote_server', 'test_remote_server']
-__version__ = '1.1'
+__version__ = '1.1.1'
 
 BINARY = re.compile('[\x00-\x08\x0B\x0C\x0E-\x1F]')
 NON_ASCII = re.compile('[\x80-\xff]')
@@ -307,7 +311,7 @@ class StaticRemoteLibrary(object):
         if __name__ == '__init__':
             return []
         kw = self._get_keyword(name)
-        args, varargs, kwargs, defaults = inspect.getargspec(kw)
+        args, varargs, kwargs, defaults, _, _, _ = getfullargspec(kw)
         if inspect.ismethod(kw):
             args = args[1:]  # drop 'self'
         if defaults:
@@ -370,8 +374,8 @@ class DynamicRemoteLibrary(HybridRemoteLibrary):
             = dynamic_method(library, 'get_keyword_tags')
 
     def _get_kwargs_support(self, run_keyword):
-        spec = inspect.getargspec(run_keyword)
-        return len(spec.args) > 3    # self, name, args, kwargs=None
+        args = getfullargspec(run_keyword)[0]
+        return len(args) > 3    # self, name, args, kwargs=None
 
     def run_keyword(self, name, args, kwargs=None):
         args = [name, args, kwargs] if kwargs else [name, args]
